summaryrefslogtreecommitdiffstats
path: root/kdat/OptionsDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/OptionsDlg.h')
-rw-r--r--kdat/OptionsDlg.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kdat/OptionsDlg.h b/kdat/OptionsDlg.h
index bd8a7de..b96fe8c 100644
--- a/kdat/OptionsDlg.h
+++ b/kdat/OptionsDlg.h
@@ -29,6 +29,7 @@ class OptionsDlgWidget;
*/
class OptionsDlg : public KDialogBase {
Q_OBJECT
+ TQ_OBJECT
private slots:
void slotOK();
void slotApply();
@@ -38,10 +39,10 @@ public:
/**
* Create a new options dialog.
*
* @param parent The parent widget of the dialog.
* @param name The name of the dialog.
*/
- OptionsDlg( TQWidget* parent = 0, const char* name = 0 );
+ OptionsDlg( TQWidget* tqparent = 0, const char* name = 0 );
/**
* Destroy the options dialog.
@@ -38,10 +39,10 @@ public:
* Create a new options dialog.
*
- * @param parent The parent widget of the dialog.
+ * @param tqparent The tqparent widget of the dialog.
* @param name The name of the dialog.
*/